@@ -50,7 +50,7 @@ cite_r <- function(file = NULL, prefix = "R-", footnote = FALSE, pkgs = NULL, om
   validate(omit, check_class = "logical", check_length = 1)
 
   r_version <- as.character(utils::packageVersion("base"))
-  cite_just_r <- paste0("R [", apa_terms$version, " ", r_version, "; @", prefix, "base]")
+  cite_just_r <- paste0("R [", apa_terms$version, " ", r_version, "\\; @", prefix, "base]")
 
   if(is.null(file) || !utils::file_test("-f", file)) { # Print R-reference if there is no .bib-file
     if(!is.null(file)) warning("File ", file, " not found. Cannot cite R-packages. If knitting again does not solve the problem, please check file path.")
@@ -121,9 +121,11 @@ cite_r <- function(file = NULL, prefix = "R-", footnote = FALSE, pkgs = NULL, om
     , pkg_keys, "]"
   )
 
-  if(length(pkg_texts) > 1) {
-    pkg_info <- paste(pkg_texts[1:(length(pkg_texts) - 1)], collapse = ", ")
-    pkg_info <- paste0(pkg_info, " ", apa_terms$and, " ", utils::tail(pkg_texts, 1))
+  if( length(pkg_texts) > 2 ) { # three or more packages: Oxford comma
+    pkg_info <- paste(pkg_texts[seq_len(length(pkg_texts) - 1)], collapse = ", ")
+    pkg_info <- paste0(pkg_info, ", ", apa_terms$and, " ", utils::tail(pkg_texts, 1))
+  } else if( length(pkg_texts) == 2 ){ # two packages: no Oxford comma
+    pkg_info <- paste(pkg_texts[[1L]], apa_terms$and, pkg_texts[[2L]])
   } else {
     pkg_info <- pkg_texts
   }
